#
# Author: Keith Vertanen
# Modified by: Michele Van Dyne
#              11/12/19 - Ported to python
#
#
# Provides the defaults of sizes, sounds, and images for a game.
# Also controls how keyboard input is mapped to an action in the game.
# By subclassing this class, you could create a new "skin" for the game.
# 
# ##### DO NOT MODIFY THIS FILE. #####
# 

from Action import Action

class Config:

    #
    # Translates a letter hit by the player into the action that that
    # key causes to happen in the game. Currently this is just the
    # cardinal direction that the hero is attempting to move in.
    # If the character isn't a direction, returns INVALID.
    # 
    # param: ch - character indicating direction of movement
    # return: action to be performed
    #
    def mapKeyToAction(self, ch):
        if ch == 'w':
            return Action.NORTH
        elif ch == 's':
            return Action.SOUTH
        elif ch == 'a':
            return Action.WEST
        elif ch == 'd':
            return Action.EAST
        else:
            return Action.INVALID
    
    #
    # Maps a specified item type to the image that is used to display it
    # 
    # param: item - the item to be mapped to an image
    # return: the file name of the image
    #
    def mapItemToImage(self, item):
        if item.name == "KEY":
            return "key.png"
        elif item.name == "GEM":
            return "gem.png"
        else:
            return ""
    
    #
    # Maps a specified item type to the sound file played when it is collected
    # 
    # param: item - the item to be mapped to a sound
    # return: the file name of the sound
    #
    def mapItemToCollectSound(self, item):
        if item.name == "KEY":
            return "key"
        elif item.name == "GEM":
            return "gem"
        else:
            return ""
     
    #
    # Maps a specified item type to the sound file played when an item is used
    # 
    # param: item - the item to be mapped to a sound
    # return: the file name of the sound
    #
    def mapItemToUseSound(self, item):
        if item.name == "KEY":
            return "open"
        else:
            return ""

    #
    # Returns the cell size in pixels
    # 
    # return: the constant 32 -- the size of the cell in pixels
    #
    def cellPixels(self):
        return 32
    
    #
    # Returns filename of the sound played when walking
    # 
    # return: the file name for the walk sound
    #
    def walkSound(self):
        return "walk"
    
    #
    # Returns filename of the sound played when hero hits a wall
    # 
    # return: the file name of the hit-the-wall sound
    #
    def hitWallSound(self):
        return "wall"
        
    #
    # Returns filename of the default image used for the hero
    # 
    # return: default file name for hero image
    #
    def heroImage(self):
        return "girl.png"

    #
    # Returns filename of the wall image
    # 
    # return: default file name for wall image
    #
    def wallImage(self):
        return "wall.png"
        
    #
    # Returns filename of the passageway image
    # 
    # return: the default file name for the passage image
    #
    def passageImage(self):
        return "passage.png"

    #
    # Returns filename of an open door image
    # 
    # return: the default file name for the open door image
    #
    def openDoorImage(self):
        return "door_open.png"

    #
    # Returns filename of a closed door image
    # 
    # return: the default file name for a closed door image
    #
    def closedDoorImage(self):
        return "door_closed.png"
